package com.example.hello14;

import android.app.Activity;
import android.content.Intent;
import android.hardware.Camera;
import android.os.Bundle;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

import org.jetbrains.annotations.Nullable;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * Created by 李祖林 on 2018/7/10.
 * 参考教程：http://www.runoob.com/w3cnote/android-tutorial-camera.html
 * 打开自定义相机的页面，调用系统相机需要加入权限。
 * 拍摄过后转入MyPreviewActiviy的ImageView显示
 * 两个Activity的交换后信息的交流用的是Intent的extra
 */

public class MyCameraActivity extends Activity {

    private SurfaceView mSurfaceView;
    private Camera mCamera = null;
    private Button mBtTake;

    private SurfaceHolder.Callback mCallBack = new SurfaceHolder.Callback() {
        @Override
        public void surfaceCreated(SurfaceHolder surfaceHolder) {
            startPerView(); //开始预览
        }

        @Override
        public void surfaceChanged(SurfaceHolder surfaceHolder, int i, int i1, int i2) {

        }

        @Override
        public void surfaceDestroyed(SurfaceHolder surfaceHolder) {
            stopPerView();  //释放资源
        }
    };

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_camera);
        bindView();
    }

    //开始预览
    private void startPerView() {
        mCamera = Camera.open();
        try {
            mCamera.setPreviewDisplay(mSurfaceView.getHolder());
//            mCamera.setDisplayOrientation(90);   //让相机旋转90度
            mCamera.startPreview();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private void bindView() {
        mSurfaceView = findViewById(R.id.surface_view);
        mBtTake = findViewById(R.id.bt_take);
        mSurfaceView.getHolder().addCallback(mCallBack);
        mBtTake.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                //Camera拍摄下照片
                mCamera.takePicture(null,null, new Camera.PictureCallback() {
                    @Override
                    public void onPictureTaken(byte[] bytes, Camera camera) {
                        String path = "";
                        if ((path = saveFile(bytes)) != null) {     //保存文件
                            Intent it = new Intent(MyCameraActivity.this, MyPreviewActivity.class);
                            it.putExtra("path", path);        //传给MyPreviewActivity，并在intent的extra部分加入图片的字节数组
                            startActivity(it);
                        } else {
                            Toast.makeText(MyCameraActivity.this, "保存照片失败", Toast.LENGTH_SHORT).show();
                        }
                    }
                });
            }
        });
    }

    private void stopPerView() {
        mCamera.stopPreview();  //停止预览
        mCamera.release();      //释放资源
        mCamera = null;
    }

    //保存临时文件的方法
    private String saveFile(byte[] bytes){
        try {
            File file = File.createTempFile("img","");
            FileOutputStream fos = new FileOutputStream(file);
            fos.write(bytes);
            fos.flush();
            fos.close();
            return file.getAbsolutePath();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return "";
    }
}
